============
Contributing
============

Contribution are welcome. You can contribute in the following ways.

+ report bugs
+ fix bugs
+ implement features
+ write documentation
+ submit feedback

Get Started
-----------

Pull / Merge Request Guidelines
-------------------------------
